@@ -37,11 +37,12 @@ def getScore(cool, coordinates,norm,header,numcores,out,mask='0'):
     unbalLib = Lib.matrix(balance=norm)
     resol = Lib._info['bin-size']
     obj = getStripe.getStripe(unbalLib, resol, 10, 8, 2.5, all_chromnames, chromnames, all_chromsizes, chromsizes,core)
+    EV = getStripe.getStripe.mpmean(obj)
     bgleft, bgright = getStripe.getStripe.nulldist(obj)
     pval = getStripe.getStripe.pvalue(obj, bgleft, bgright, table)
     table.insert(table.shape[1],'pvalue_added',pval,True)
     MEAN, SUM = getStripe.getStripe.getMean(obj,table)
-    s,MEANOE,TOTALOE = obj.scoringstripes(table,mask)
+    s,MEANOE,TOTALOE = getStripe.getStripe.scoringstripes(obj, table, EV, mask)
     table.insert(table.shape[1],'Stripiness_added',s,True)
     table.insert(table.shape[1], "O_Mean_added", MEAN, True)
     table.insert(table.shape[1], "O_Sum_added", SUM, True)
